@@ -3,7 +3,7 @@ function (Bdata)
 {   z<- check.par (Bdata)
 	format.in <- attr(Bdata,"format.date") 
 	if (format.in=="age"|format.in=="ages") Bdata2 <- Bdata else 
-	  	Bdata2 <- date.b(Bdata=Bdata,format.in=format.in,format.out="age")
+	  	Bdata2 <- date_b(Bdata=Bdata,format.in=format.in,format.out="age")
     nsample <- nrow(Bdata2)
 	maxtrans <- (ncol(Bdata2)-locpath(Bdata2))
    ages <- array(0,c(nrow(Bdata2),maxtrans))
@@ -12,9 +12,10 @@ function (Bdata)
    dimnames (ages) <- list (ID=Bdata2$ID,paste("tr",1:maxtrans,sep=""))
    ageentry <- Bdata2$start
    agecens <- Bdata2$end
+   ns = nchar (Bdata2$path)
    return (list (ages =ages,
                  ageentry = ageentry,
                  agecens = agecens,
                  st_entry = substr(Bdata2$path,1,1),
-                 st_censoring = substr(Bdata2$path,Bdata2$ns,Bdata2$ns)))
+                 st_censoring = substr(Bdata2$path,ns,ns)))
 }
