@@ -4,14 +4,16 @@ function (Bdata)
   # Remove records with end < start
   Bdata2 <- subset (Bdata[Bdata$end-Bdata$start >= 0,]) # was: Bdata
   attr(Bdata2,"format.date") <- format.in <- attr(Bdata,"format.date")
-  attr(Bdata2,"trans") <- attr(Bdata,"trans")
-  if (!is.null(attr(Bdata2,"trans"))) tmat <- attr(Bdata2,"trans") else 
-            #  tmat <- ex_Bdata$tmat 
-     {print ("Biograph.long: Parameters missing. Biograph runs Parameters . . . . ",quote=FALSE)
-      ex_Bdata <- Parameters(Bdata2)
-      attr(Bdata2,"trans") <- ex_Bdata$tmat
-      tmat <- ex_Bdata$tmat
-     }
+  if (is.null(attr(Bdata,"param"))) print ("Biograph.long: Parameters missing. Run Parameters . . . . ",quote=FALSE)
+  tmat <- attr(Bdata,"param")$tmat
+ # attr(Bdata2,"trans") <- attr(Bdata,"trans")
+ # if (!is.null(attr(Bdata2,"trans"))) tmat <- attr(Bdata2,"trans") else 
+ #           #  tmat <- ex_Bdata$tmat 
+ #    {print ("Biograph.long: Parameters missing. Biograph runs Parameters . . . . ",quote=FALSE)
+ #     ex_Bdata <- Parameters(Bdata2)
+ #     attr(Bdata2,"trans") <- ex_Bdata$tmat
+ #     tmat <- ex_Bdata$tmat
+ #    }
   print (". . . . .  Creating long format  . . . . . .",quote=FALSE)
   Bdata2$start2 <- Bdata2$start
   locpat <- locpath(Bdata2)
@@ -23,6 +25,7 @@ function (Bdata)
   D <- zx2[do.call("order",list(zx2$ID,zx2$date)),] # sort by 2 variables
   print (" . . . . Adjust long format for survival package etc . . .  ",quote=FALSE)
   D$OD <- substr(paste("B",D$path,"Ce",sep=""),D$time,D$time+1)
+  D$ns <- nchar(D$path)
   D$time <- ifelse (D$time==max(D$time),D$ns+1,D$time)   # time = line number of episode in trajectory (first= from birth; last = open to censored)
   D$OD[D$time==D$ns+1]<- "cens"
   D$Tstart <- rep(0,nrow(D))
@@ -31,18 +34,19 @@ function (Bdata)
   D$Tstop <- D$date
 
 # ----------------------------------
-  max_ns <- max(Bdata2$ns)
+  ns <- nchar(Bdata2$path)
+  max_ns <- max(ns)
  # D8 <- subset(D,D$Tstart != D$Tstop & D$Tstart >= D$born)  # remove first episode (birth to entry in first state)  was: D$date!=D$born & 
   D8<- subset (D,D$time<=(max(D$ns)+1))  # & D$OD!="")
   D8 <-subset (D8,D8$time!=1)
-  D8 <- subset (D8,!(D8$date==D8$Tstart & D8$time==(max(Bdata2$ns+1))))
+  D8 <- subset (D8,!(D8$date==D8$Tstart & D8$time==(max_ns+1)))
    #  in Jan 2012, D8$born was replaced by D8$Tstart (running format.dat=age)
    # and ChangeObservationWindow.t to start at age 10 (GLHS)
   D_negative <- subset (D8,D8$Tstop-D8$Tstart < 0) # = empty
   D <- D8
     # Check whether duration is nonnegative (for Lexislines): select records with neg values
     # result should be same as sum(Bdata$ns)
-  if (nrow(D)!=sum(Bdata2$ns)) warning (paste("Biograph.long: Number of records in long format differs from total number of episodes in Biograph object: ",nrow(D)," versus ",sum(Bdata2$ns),sep=""))
+  if (nrow(D)!=sum(ns)) warning (paste("Biograph.long: Number of records in long format differs from total number of episodes in Biograph object: ",nrow(D)," versus ",sum(ns),sep=""))
   # At birth: state is B or first state of state sequence
   CC <- "B"
   CC <- substr(D$path,1,1)
@@ -52,14 +56,16 @@ function (Bdata)
   # D$DES <- ifelse (D$time > D$ns,"cens",substr(D$path,(D$time),(D$time)))
   D$status <- ifelse (D$DES=="cens",0,1)
   zloc=10
+  ncovariates <- attr(Bdata,"param")$ncovariates
+   namstates <-   attr(Bdata,"param")$namstates
   D$trans <- apply(D,1,function (x) {ifelse (x[ncovariates+zloc+2]=="cens", 
            grep(x[ncovariates+zloc+1],namstates),
            tmat[grep(x[ncovariates+zloc+1],namstates),grep(x[ncovariates+zloc+2],namstates)])})
 # D$trans changed october 2011
   code88 <- ifelse(format.in=="CMC",12,1)
   D$birthdate <- D$born
-  if (class(D$born)=="Date") D$birthyear <- Date.as.year (D$born) else 
-     {{ if (attr(Bdata,"format.date")=="CMC"|attr(Bdata,"format.date")=="cmc")  D$birthyear <- 1900 + D$born/12 else
+  if (class(D$born)=="Date") D$birthyear <- Date_as_year (D$born) else 
+     {{ if (attr(Bdata,"format.date")=="CMC"|attr(Bdata,"format.date")=="cmc") D$birthyear <- date_convert (D$born,format.in="CMC",format.out="year") else
      	  { if (attr(Bdata,"format.date")=="year"|attr(Bdata,"format.date")=="age"|attr(Bdata,"format.date")=="numeric")  D$birthyear <- D$born else D$birthyear <- D$born}
      }}	  
   if (attr(Bdata,"format.date") == "age") D$born <- rep(0,nrow(D)) 
@@ -73,8 +79,8 @@ function (Bdata)
                 birhtdate=De$birthdate,birthyear=D$birthyear,De[,(3:(2+ncovariates))],
                 born=De$born,OD=De$OD,Episode=De$time,Tstarta=D$Tstarta,Tstopa=D$Tstopa)
                          
-  attr(D, "trans") <- tmat   
-  attr(Depisode, "trans") <- tmat  
+  attr(D, "param") <- attr(Bdata,"param")  
+  attr(Depisode, "param") <- attr(Bdata,"param") 
   attr(D, "format.date") <- attr(Bdata,"format.date")   
   attr(Depisode, "format.date") <- attr(Bdata,"format.date") 
 
