@@ -6,7 +6,7 @@ function (Bdata,transition,title,cov,legend)
   if (missing(title)) title <- "Title missing" 
   if (missing(legend)) legend <- "topleft"
  # year <- data.frame(YearTrans(Bdata))
-  Bdata2 <- date.b(Bdata=Bdata,format.in="CMC",selectday=1,format.out="year")  
+  Bdata2 <- date_b(Bdata=Bdata,format.in="CMC",selectday=1,format.out="year")  
   zx <- TransitionAB(Bdata2,transition) # zx: nrow = number of transition selected
   Bdata2 <- subset(Bdata2,!is.na(zx$year))
   ID <- zx$id
